#
# spec file for package python-tooz
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pypi_name tooz
Name:           python-tooz
Version:        1.43.0
Release:        2.4
Summary:        Coordination library for distributed systems
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://docs.openstack.org/developer/tooz/
Source0:        https://pypi.io/packages/source/t/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python-devel
BuildRequires:  python-pbr >= 1.6
BuildRequires:  python-setuptools >= 16.0
BuildRequires:  python-testtools >= 1.4.0
Requires:       python-Babel >= 2.3.4
Requires:       python-enum34
Requires:       python-fasteners >= 0.7
Requires:       python-futures >= 3.0
Requires:       python-futurist >= 0.11.0
Requires:       python-iso8601 >= 0.1.11
Requires:       python-msgpack-python >= 0.4.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.utils >= 3.16.0
Requires:       python-retrying >= 1.2.3
Requires:       python-six >= 1.9.0
Requires:       python-stevedore >= 1.16.0
Requires:       python-voluptuous >= 0.8.9
Requires:       python-zake >= 0.1.6
BuildArch:      noarch

%description
The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-enum34
BuildRequires:  python-futures >= 3.0
BuildRequires:  python-oslo.utils >= 3.16.0
BuildRequires:  python-oslosphinx >= 2.5.0
BuildRequires:  python-stevedore >= 1.16.0

%description doc
The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications.

This package contains documentation in HTML format.

%prep
%setup -q -n %{pypi_name}-%{version}

%build
%py2_build

# generate html docs
%{__python2} setup.py build_sphinx
# remove the Sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%check
%{__python2} setup.py testr

%install
%py2_install

%files
%license LICENSE
%doc README.rst
%{python2_sitelib}/%{pypi_name}
%{python2_sitelib}/%{pypi_name}-*.egg-info

%files doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Sep 30 2016 dmueller@suse.com
- update to 1.43.0:
  * Makedirs only throws oserror, so only catch that
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.42.0
  * Share _get_random_uuid() among all tests
  * Fix the test test_unwatch_elected_as_leader.
  * etcd: don't run heartbeat() concurrently
  * File driver: properly handle Windows paths
  * etcd: properly block when using 'wait'
  * Clean leave group hooks when unwatching.
  * Updated from global requirements
* Tue Aug  9 2016 tbechtold@suse.com
- update to 1.40.0:
  * Add docs for new consul driver
  * Change dependency to use flavors
  * Run doc8 only in pep8 target
  * Move pep8 requirements in their own target
  * zookeeper: do not hard depend on eventlet
  * Remove unused iso8601 dependency
  * tests: remove testscenario usage
  * file: set no timeout by default
  * tests: move bad_url from scenarios to static test
  * Expose timeout capabilities and use them for tests
  * Use pifpaf to setup daemons
  * Updated from global requirements
  * Using LOG.warning instead of LOG.warn
  * redis: do not force LuaLock
  * Fix coordinator typo
  * Ensure etcd is in developer and driver docs
  * Remove unused consul future result
  * Add a consul based driver
  * file: make python2 payload readable from python3
- update _service and switch to upstream spec.j2 template
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.34.0:
  * Updated from global requirements
  * Compute requires_beating
  * Fix calling acquire(blocking=False) twice leads to a deadlock
  * Raises proper error when unwatching a group
  * Updated from global requirements
  * Updated from global requirements
  * Add .tox, *.pyo and *.egg to .gitignore
  * Enable OS_LOG_CAPTURE so that logs can be seen (on error)
  * Updated from global requirements
  * Add lock breaking
  * pgsql: fix hostname parsing
  * Updated from global requirements
  * Updated from global requirements
  * Update voluptuous requirement
  * Updated from global requirements
  * Updated from global requirements
  * Have zookeeper heartbeat perform basic get
  * Add desired characteristics strict subset validation
  * Add base64 key encoder (and validations)
  * Use voluptuous instead of jsonschema
  * Add programatic introspection of drivers characteristic(s)
  * Updated from global requirements
  * pep8: fix remaining errors and enable all checks
  * Use utils.convert_blocking to convert blocking argument
  * Adjust some of the zookeeper exception message
  * Fix etcd env setup
  * tests: do not hardcode /tmp
  * utils: replace exception_message by exception_to_unicode
  * Add a default port and default host
  * etcd: driver with lock support
  * Use utils.to_binary instead of using redis module equivalent
  * Remove tested under 2.6 from docs
- adjust Requires according to requirements.txt
* Mon Jan  4 2016 tbechtold@suse.com
- update to 1.29.0:
  * Updated from global requirements
  * Add basic file content schema validation
  * Spice up the driver summary/info page
  * Make all locks operate the same when fetched from different coordinators
  * Add noted driver weaknesses onto the drivers docs
  * Updated from global requirements
  * File: read member id from file with suffix ".raw"
  * Reduce duplication of code in handling multi-type blocking argument
  * Updated from global requirements
  * Add comment in memcache explaining the current situation with lock release
  * Add 'requires_beating' property to coordination driver
  * {pg,my}sql: fix AttributeError on connection failure
  * tests: allow ipc to bypass blocking=False test
  * pgsql: remove unused left-over code
  * Add 'is_still_owner' lock test function
  * Updated from global requirements
  * Updated from global requirements
  * Remove python 2.6 and cleanup tox.ini
  * Updated from global requirements
  * Allow specifying a kazoo async handler 'kind'
  * Updated from global requirements
  * Updated from global requirements
  * Add standard code coverage configuration file
  * docs - Set pbr 'warnerrors' option for doc build
  * Include changelog/history in docs
  * Updated from global requirements
  * Expose Znode Stats and Capabilities
  * Allow more kazoo specific client options to be proxied through
  * Updated from global requirements
- add _service file
- adjust Requires according to requirements.txt
* Tue Sep  1 2015 tbechtold@suse.com
- update to 1.23.0:
  * Changes to add driver list to the documentation
  * Updated from global requirements
  * Updated from global requirements
  * Accept blocking argument in lock's context manager
  * Make RedisLock's init consistent with other locks
  * Updated from global requirements
  * Raise exception on failed lock's CM acquire fail
  * Be more restrictive on the executors users can provide
  * Updated from global requirements
  * Updated from global requirements
  * Use futurist to allow for executor providing and unifying
  * Use a lua script(s) instead of transactions
  * Updated from global requirements
  * Change Lock.name to a property
  * Update .gitignore
  * Updated from global requirements
  * Fixup dependencies
  * Expose started state of coordinator to external
  * Updated from global requirements
  * Updated from global requirements
  * Remove tooz/openstack as it is empty and not used
  * Fix sp 'seonds' -> 'seconds'
  * Ensure run_watchers called from mixin, not base class
  * Updated from global requirements
  * Update compatibility matrix due to file drivers new abilities
- Adjust Requires according to requirements.txt
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Fri Jul  3 2015 dmueller@suse.com
- update to 0.17.0:
  * Ensure unwatch_elected_as_leader correctly clears hooks
* Wed Jun 24 2015 tbechtold@suse.com
- update to 0.16.0:
  * Updated from global requirements
  * Ensure lock(s) acquire/release returns boolean values
  * Remove file-driver special no-async abilities
  * Delay interpolating the LOG string
  * Use `encodeutils.exception_to_unicode` for exception -> string function
  * Use the `excutils.raise_with_cause` after doing our type check
  * Updated from global requirements
  * Use the 'driver_lock' around read operations
  * Updated from global requirements
  * Switch badges from 'pypip.in' to 'shields.io'
  * Updated from global requirements
  * Add watch file driver support
  * Make the file driver more capable (with regard to groups)
  * Ensure locks can not be created outside of the root file driver directory
  * Updated from global requirements
  * Use MySQL default port when not set explicitly
  * Use fasteners library for interprocess locks
  * Implement watch/unwatch elected_as_leader for redis driver
  * Updated from global requirements
  * Use lua locks instead of pipeline locks
  * Move more string constants to class constants with docstrings
  * Updated from global requirements
  * Updated from global requirements
  * Remove support for redis < 2.6.0
  * Expose Zookeeper client class constants
  * Expose redis client class constants
  * Use a serialization/deserialization specific exception
  * Expose memcache coord. class constants
  * Explicitly start and execute most transactions
  * Provide and use a options collapsing function
  * Add zookeeper tag in setup.cfg
  * Use pymemcache pooled client
  * Use oslo.serialization msgpackutils
  * Provide ability for namespace customization for Zookeeper and Zake drivers
  * Typo in Locking doc
  * Move optional driver requirements to test-requirements.txt
  * Have run_watchers take a timeout and respect it
  * Heartbeat on acquired locks copy
  * Avoid using a thread local token storage
  * Fix param name to be its right name
  * Replace more instance(s) of exception chaining with helper
  * Just use staticmethod functions to create _dumps/_loads
  * Uncap library requirements for liberty
  * Link AOF to redis persistence docs
  * Add exception docs to developer docs
  * Add + use helper to raise + chain exceptions
  * Allow the acquired file to be closed manually
  * Updated from global requirements
  * Silence logs + errors when stopping and group membership lost
  * Make and use a thread safe pymemcache client subclass
  * Handle errors that come out of pymemcache better
  * Use rst inline code structure + link to sentinel
  * Beef up the docstrings on the various drivers
  * fix lock concurrency issues with certain drivers
  * Add pypi download + version badges
  * Denote that 2.6 testing is still happening
  * Updated from global requirements
  * Use a sentinel connection pool to manage failover
  * fix mysql driver url parsing
- Adjust Requires according to requirements.txt
* Wed Apr  8 2015 tbechtold@suse.com
- update to 0.13.1:
  * Switch to non-namespaced module imports
  * Add a driver feature compatibility matrix
  * Remove support for 3.3
  * Two locks acquired from one coord must works
  * Updated from global requirements
  * Releases locks in tests
  * Allow coordinator non-string options and use them
  * Since we use msgpack this can be more than a str
  * Updated from global requirements
- update Requires according to requirements.txt
* Thu Feb 26 2015 tbechtold@suse.com
- update to 0.12:
  * retry: fix decorator
  * file: fix typo in errno.EACCES
  * Add a file based driver
  * Upgrade to hacking 0.10
  * Update sentinel support to allow multiple sentinel hosts
  * Allow to pass arguments to retry()
  * IPC simplification
* Thu Jan  8 2015 tbechtold@suse.com
- update to version 0.10:
  * Add support for an optional redis-sentinel
  * README.rst tweaks
  * A few more documentation tweaks
  * Sync requirements to global requirements
  * Add create/join/leave group support in IPC driver
  * Add driver autogenerated docs
  * Update links + python version supported
  * zookeeper: add support for delete group
  * redis: add support for group deletion
  * tests: minor code simplification
  * memcached: add support for group deletion
  * memcached: add support for _destroy_group
  * Switch to using oslosphinx
  * Add doc on how transaction is itself retrying internally
  * Fix .gitreview after rename/transfer
  * tests: use scenarios attributes for timeout capability
  * tests: check for leave group events on dead members cleanup
  * memcached: delete stale/dead group members on get_members()
  * tests: remove check_port
  * tests: do not skip test on connection error
  * doc: add missing new drivers
  * doc: switch examples to Zake
  * doc: add locking
  * Fix tox envlist
  * Drop Python 3.3 tests in tox
  * Allow tox with py34 and MySQL
  * Test connection error scenarios on more drivers
  * Translate psycopg2 errors/exceptions into tooz exceptions
  * Ensure 'leave_group' result gotten before further work
  * watch_leave_group not triggering callback on expired members
  * Add MySQL driver
  * Discard 'self' from '_joined_groups' if we got booted out
  * Implement non-blocking locks with PostgreSQL
  * More retry code out of memcached
  * Add a PostgreSQL driver
  * Fix gate
  * Handle when a group used to exist but no longer does
  * tox: split redis/memcached env
  * Fix memcached heartbeat on start()
  * tox: splits test scenarios
  * Add a minimum redis version check while starting
  * Make requirement on redis 2.10.x explicit
  * Try to use PSETEX when possible
  * Use hdel with many keys where supported
  * Avoid logging warnings when group deleted or member gone
  * Ensure that we correctly expire (and cleanup) redis members
  * Various fixes for locks and version compatibility
  * Move sysv_ipc deps to test-requirements
  * test: try to stop() first
  * Convert the rest of memcached driver functions to futures
  * Add a assertRaisesAny helper method
  * Allow zake to be tested
  * Add a redis driver
  * Ensure groups leaving returns are gotten
  * Raise the new OperationTimedOut when futures don't finish
  * Start to add a catch and reraise of timed out exceptions
  * Adjust the timeout to reflect the repeated retries
  * ipc: do not delete the lock if we never acquired it
  * Add home-page field
  * Split up the requirements for py2.x and py3.x
  * ipc: Fix acquire lock loop logic
  * Make lock blocking with no time out by default
  * coordination: remove destroy() from the lock protocol
  * IPC: fix a potential race condition at init
  * Fix IPC driver on OS X
  * Switch to oslo.utils
  * Blacklist retrying 1.3.0
  * Use futures to make parts of the memcached driver async
  * Have examples run in the py27 environment and make them work
- Adjust Requires according requirements.txt
* Fri Nov 14 2014 dmueller@suse.com
- python-subunit removed from runtime requires, its a test only
  require
* Fri Oct  3 2014 iartarisi@suse.com
- Add python-sysv_ipc requirement from requirements.txt file
* Tue Sep 30 2014 dmueller@suse.com
- update to 0.4:
  * Standardize the async result subclasses
  * Fix the comment which was borrowed from the IPC driver
  * Be more tolerant of unicode exceptions
  * Standardize on the same lock acquire method definition
  * Standardize on hiding the lock implementation
  * On lock removal validate that they key was actually deleted
  * Use a thread safe deque instead of a queue
  * Change inline docs about class fake storage variable
  * LOG a warning if the heartbeat can not be validated
  * Add doc8 to the py27 test running
  * Use the more reliable sysv_ipc instead of posix_ipc+lockutils
  * Only start zookeeper/memcached when not already running
  * Let zake act as a in-memory fully functional driver
  * Switch to a custom NotImplemented error
  * Ensure lock list isn't mutated while iterating
  * Move Zake driver code to separated Python module
  * Work toward Python 3.4 support and testing
  * Unlock the kazoo version
  * Bump up zake to be using the newer 0.1 or greater
  * Fix zake driver with latest release
  * memcached: switch leader election implementation to a lock
  * Add the generation of the documentation in tox.ini
  * Add coverage report
- fix package requires
* Wed Sep  3 2014 dmueller@suse.com
- update to 0.3:
  * Switch to URL for loading backends
  * Import network_utils from Oslo
  * coordination: add IPC driver
  * coordination: raise NotImplementedError as default
  * Add documentation
  * Upgrade hacking requirement
  * memcached: use retrying rather than sleeping
  * Use retrying instead of our custom code
  * Update requirements file matching global requ
  * memcached: implement leader election
  * Fix a race condition in one of the test
* Sun Jun  1 2014 thomasbechtold@jpberlin.de
- Initial version.
